==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/GetStatisticsResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetStatisticsResponse(
    statistics: Optional[zio.aws.iot.model.Statistics] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.GetStatisticsResponse = {
    import GetStatisticsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.GetStatisticsResponse
      .builder()
      .optionallyWith(statistics.map(value => value.buildAwsValue()))(
        _.statistics
      )
      .build()
  }
  def asReadOnly: zio.aws.iot.model.GetStatisticsResponse.ReadOnly =
    zio.aws.iot.model.GetStatisticsResponse.wrap(buildAwsValue())
}
object GetStatisticsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.GetStatisticsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.GetStatisticsResponse = zio.aws.iot.model
      .GetStatisticsResponse(statistics.map(value => value.asEditable))
    def statistics: Optional[zio.aws.iot.model.Statistics.ReadOnly]
    def getStatistics
        : ZIO[Any, AwsError, zio.aws.iot.model.Statistics.ReadOnly] =
      AwsError.unwrapOptionField("statistics", statistics)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.GetStatisticsResponse
  ) extends zio.aws.iot.model.GetStatisticsResponse.ReadOnly {
    override val statistics: Optional[zio.aws.iot.model.Statistics.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statistics())
        .map(value => zio.aws.iot.model.Statistics.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.GetStatisticsResponse
  ): zio.aws.iot.model.GetStatisticsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/GetStatisticsResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetStatisticsResponse(
    statistics: Option[zio.aws.iot.model.Statistics] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.GetStatisticsResponse = {
    import GetStatisticsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.GetStatisticsResponse
      .builder()
      .optionallyWith(statistics.map(value => value.buildAwsValue()))(
        _.statistics
      )
      .build()
  }
  def asReadOnly: zio.aws.iot.model.GetStatisticsResponse.ReadOnly =
    zio.aws.iot.model.GetStatisticsResponse.wrap(buildAwsValue())
}
object GetStatisticsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.GetStatisticsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.GetStatisticsResponse = zio.aws.iot.model
      .GetStatisticsResponse(statistics.map(value => value.asEditable))
    def statistics: Option[zio.aws.iot.model.Statistics.ReadOnly]
    def getStatistics
        : ZIO[Any, AwsError, zio.aws.iot.model.Statistics.ReadOnly] =
      AwsError.unwrapOptionField("statistics", statistics)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.GetStatisticsResponse
  ) extends zio.aws.iot.model.GetStatisticsResponse.ReadOnly {
    override val statistics: Option[zio.aws.iot.model.Statistics.ReadOnly] =
      scala
        .Option(impl.statistics())
        .map(value => zio.aws.iot.model.Statistics.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.GetStatisticsResponse
  ): zio.aws.iot.model.GetStatisticsResponse.ReadOnly = new Wrapper(impl)
}
